==> tecfy_basic_package-1.0.2.tar.gz: lib/services/layout.service.dart <==
part of tecfy_basic_package;

class LayoutService {
  static bool isMobile(BuildContext context) {
    return MediaQuery.of(context).size.width < 900 &&
        MediaQuery.of(context).orientation == Orientation.portrait;
  }

  static double getWidth(BuildContext context) {
    return MediaQuery.of(context).size.width;
  }

  static double getHeight(BuildContext context) {
    return MediaQuery.of(context).size.height;
  }

  static bool disableAnimation(BuildContext context) {
    return kIsWeb || MediaQuery.of(context).disableAnimations;
  }

  static bool isTablet(BuildContext context) {
    return (MediaQuery.of(context).size.width >= 900 &&
            MediaQuery.of(context).size.width < 1200) ||
        (MediaQuery.of(context).orientation == Orientation.landscape &&
            MediaQuery.of(context).size.width < 1200);
  }

  static bool isDesktop(BuildContext context) {
    return MediaQuery.of(context).size.width >= 1200;
  }

  static Widget bindWidget(BuildContext context,
      {Widget? mobileWidget,
      Widget? tabletWidget,
      Widget? descktopWidget}) //: assert(context != null)
  {
    //return descktopWidget;
    if (MediaQuery.of(context).size.width > 1200)
      return descktopWidget ?? tabletWidget ?? mobileWidget ?? Container();

    if (MediaQuery.of(context).size.width > 900 ||
        MediaQuery.of(context).orientation == Orientation.landscape)
      return tabletWidget ?? descktopWidget ?? mobileWidget ?? Container();

    return mobileWidget ?? tabletWidget ?? descktopWidget ?? Container();
  }
}

==> tecfy_basic_package-1.0.6.tar.gz: lib/services/layout.service.dart <==
part of tecfy_basic_package;

class LayoutService {
  static bool isMobile(BuildContext context) {
    return MediaQuery.of(context).size.width < 900 &&
        MediaQuery.of(context).orientation == Orientation.portrait;
  }

  static double getWidth(BuildContext context) {
    return MediaQuery.of(context).size.width;
  }

  static double getHeight(BuildContext context) {
    return MediaQuery.of(context).size.height;
  }

  static bool disableAnimation(BuildContext context) {
    return kIsWeb || MediaQuery.of(context).disableAnimations;
  }

  static bool isTablet(BuildContext context) {
    return (MediaQuery.of(context).size.width >= 900 &&
            MediaQuery.of(context).size.width < 1200) ||
        (MediaQuery.of(context).orientation == Orientation.landscape &&
            MediaQuery.of(context).size.width < 1200);
  }

  static bool isDesktop(BuildContext context) {
    return MediaQuery.of(context).size.width >= 1200;
  }

  static Widget bindWidget(BuildContext context,
      {Widget Function()? mobileWidget,
      Widget Function()? tabletWidget,
      Widget Function()? descktopWidget}) //: assert(context != null)
  {
    //return descktopWidget;
    if (MediaQuery.of(context).size.width > 1200) {
      var c =
          descktopWidget ?? tabletWidget ?? mobileWidget ?? () => Container();
      return c();
    }
    if (MediaQuery.of(context).size.width > 900 ||
        MediaQuery.of(context).orientation == Orientation.landscape) {
      var c =
          tabletWidget ?? descktopWidget ?? mobileWidget ?? () => Container();
      return c();
    }

    var c = mobileWidget ?? tabletWidget ?? descktopWidget ?? () => Container();
    return c();
  }
}
